==> haskell-criterion-1.5.12.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 criterion
version:              1.5.12.0
visibility:           public
id:                   criterion-1.5.12.0-7f4uKwLJGLcCSefcdPOInX
key:                  criterion-1.5.12.0-7f4uKwLJGLcCSefcdPOInX
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/criterion
synopsis:             Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.

    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.

category:             Development, Performance, Testing, Benchmarking
abi:                  d191edc6cbf16ed5e2ce2dbe277db95c
exposed:              True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types

hidden-modules:       Criterion.Monad.Internal Paths_criterion
import-dirs:          /usr/lib/ghc-9.0.2/site-local/criterion-1.5.12.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/criterion-1.5.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion
hs-libraries:         HScriterion-1.5.12.0-7f4uKwLJGLcCSefcdPOInX
depends:
    Glob-0.10.2-FEEgHol6baS2O0df0TvMv1
    aeson-1.5.6.0-AKViGrmijRVB0tE3IZiiOh
    ansi-wl-pprint-0.6.9-J38Hi5Z6ALfKDwm9oxcbks base-4.15.1.0
    base-compat-batteries-0.12.1-4nbuJ6lBhTeKCqSgDg2TuK binary-0.8.8.0
    binary-orphans-1.0.2-ADop7fXgFHDBcQL6VUanS6 bytestring-0.10.12.1
    cassava-0.5.3.0-9PeIaeRVEwW9yCEAzRbLAK
    code-page-0.2.1-2yvmeM0b2LT6XlGG4kufG5 containers-0.6.4.1
    criterion-measurement-0.1.3.0-J646Jkj9s8yDQAWwoN1RoJ
    deepseq-1.4.5.0 directory-1.3.6.2 exceptions-0.10.4
    filepath-1.4.2.1 js-chart-2.9.4.1-Flj5BKolsep7sdg9Mb6p76
    microstache-1.0.2.1-HNuLmUX7hT3AAWJxEyQ6dX mtl-2.2.2
    mwc-random-0.15.0.2-7HYBYniswJuCoqPhvFbL6q
    optparse-applicative-0.16.1.0-BKNPip5PGw2CnbOiekISfW
    parsec-3.1.14.0 statistics-0.16.0.2-I52sfKHQYSWLy7qcqUAeOP
    text-1.2.5.0 time-1.9.3 transformers-0.5.6.2
    transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH
    vector-0.12.3.1-DWLcs41oUpGB6FR7Q3d3DL
    vector-algorithms-0.8.0.4-gUfDU83eTALlS5Ep3VAPq

haddock-interfaces:   /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html:         /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-1.5.13.0-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 criterion
version:              1.5.13.0
visibility:           public
id:                   criterion-1.5.13.0-B7XtbvrdA2c149cAZGRS44
key:                  criterion-1.5.13.0-B7XtbvrdA2c149cAZGRS44
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/criterion
synopsis:             Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.

    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.

category:             Development, Performance, Testing, Benchmarking
abi:                  ee9ade7f5ff828c5329e5e165e00011f
exposed:              True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types

hidden-modules:
    Criterion.Main.Options.Internal Criterion.Monad.Internal
    Paths_criterion

import-dirs:          /usr/lib/ghc-9.0.2/site-local/criterion-1.5.13.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/criterion-1.5.13.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion
hs-libraries:         HScriterion-1.5.13.0-B7XtbvrdA2c149cAZGRS44
depends:
    Glob-0.10.2-K3hmTBdRsZw8onVwFa5nKM
    aeson-1.5.6.0-6rBoO6bU0Qo8Yma8Si89de
    ansi-wl-pprint-0.6.9-J38Hi5Z6ALfKDwm9oxcbks base-4.15.1.0
    base-compat-batteries-0.12.2-IRMWCUzsfqD6zrAxpQ8pvB binary-0.8.8.0
    binary-orphans-1.0.2-KUCHETfPPouKnRYHRTT8pb bytestring-0.10.12.1
    cassava-0.5.3.0-5F5vrv7ad0x3GR6OQgzb0Q
    code-page-0.2.1-2yvmeM0b2LT6XlGG4kufG5 containers-0.6.4.1
    criterion-measurement-0.1.3.0-IzSzL5kFo1QL3jFjMYxQRB
    deepseq-1.4.5.0 directory-1.3.6.2 exceptions-0.10.4
    filepath-1.4.2.1 js-chart-2.9.4.1-Flj5BKolsep7sdg9Mb6p76
    microstache-1.0.2.2-F9Kkgnb3L0qAgiYwjAA7xX mtl-2.2.2
    mwc-random-0.15.0.2-9DCWARoB2KzBlqKggTWvzX
    optparse-applicative-0.16.1.0-BKNPip5PGw2CnbOiekISfW
    parsec-3.1.14.0 statistics-0.16.0.2-9KGibyw2mObAqZN0JlRVN5
    text-1.2.5.0 time-1.9.3 transformers-0.5.6.2
    transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH
    vector-0.12.3.1-37YOJsTp4sSIT9CMAp9q9Q
    vector-algorithms-0.8.0.4-8KiJAuhtno1CMn91N29o50

haddock-interfaces:   /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html:         /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
